#ifndef NT2_INCLUDE_CONSTANTS_FASTGAMMALARGELIM_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_FASTGAMMALARGELIM_HPP_INCLUDED

#include <nt2/euler/include/constants/fastgammalargelim.hpp>

#endif
